#ifndef _COMP_BZLIB_H
#define _COMP_BZLIB_H
#include "dact.h"
#include "config.h"

#if defined(USE_MODULES) && !defined(AS_MODULE)
#define comp_bzlib_algo DACT_FAILED_ALGO
#else
int comp_bzlib_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
int comp_bzlib_compress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
int comp_bzlib_decompress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
#endif
#endif
